<?php
/**
 * Core plugin class
 *
 * @package SSSI
 */

if (!defined('ABSPATH')) {
    exit;
}

class SSSI_Core {
    /**
     * Settings instance
     *
     * @var SSSI_Settings
     */
    private $settings;

    /**
     * Frontend instance
     *
     * @var SSSI_Frontend
     */
    private $frontend;

    /**
     * Initialize the plugin
     */
    public function __construct() {
        try {
            // Initialize settings first
            $this->settings = new SSSI_Settings();
            
            // Register hooks
            add_action('admin_enqueue_scripts', array($this, 'register_admin_assets'));
            add_action('wp_enqueue_scripts', array($this, 'register_frontend_assets'));
            add_shortcode('sssi', array($this, 'render_shortcode'));
            
            // Initialize frontend if not in admin
            if (!is_admin()) {
                $this->frontend = new SSSI_Frontend($this->settings);
                $this->frontend->init();
            }

            sssi_debug_log('Core initialized successfully');

        } catch (Exception $e) {
            sssi_debug_log('Core initialization error', array(
                'error' => $e->getMessage(),
                'trace' => $e->getTraceAsString()
            ));
            throw $e;
        }
    }

    /**
     * Register admin assets
     */
    public function register_admin_assets($hook) {
        if ('toplevel_page_sssi-settings' !== $hook) {
            return;
        }

        // Get all network icons first
        $networks = array('facebook', 'x', 'linkedin', 'pinterest', 'whatsapp', 'bluesky');
        $icons = array();
        foreach ($networks as $network) {
            $icons[$network] = SSSI_Icons::get_network_icon($network);
        }

        // Get current options and defaults
        $options = $this->settings->get_options();
        $defaults = self::get_default_options();

        // Register and localize script BEFORE enqueueing
        wp_register_script(
            'sssi-admin',
            SSSI_PLUGIN_URL . 'assets/js/sssi-admin.js',
            array('jquery'),
            SSSI_VERSION,
            true
        );

        // Localize script with all necessary data
        wp_localize_script('sssi-admin', 'SSSI', array(
            'icons' => $icons,
            'defaults' => $defaults,
            'options' => $options,
            'networks' => SSSI_Icons::get_available_networks(),
            'debug' => WP_DEBUG,
            'pluginUrl' => SSSI_PLUGIN_URL,
            'nonce' => wp_create_nonce('sssi_settings_nonce')
        ));

        // Register styles with cache-busting version
        wp_enqueue_style(
            'sssi-shared',
            SSSI_PLUGIN_URL . 'assets/css/sssi-shared.css',
            array(),
            SSSI_VERSION . '.' . time() // Add timestamp for development
        );

        wp_enqueue_style(
            'sssi-admin',
            SSSI_PLUGIN_URL . 'assets/css/sssi-admin.css',
            array('sssi-shared'),
            SSSI_VERSION . '.' . time() // Add timestamp for development
        );

        // Now enqueue the script
        wp_enqueue_script('sssi-admin');

        sssi_debug_log('Admin assets registered with data', array(
            'icons' => array_keys($icons),
            'options' => $options,
            'defaults' => $defaults,
            'hook' => $hook,
            'icons_data' => $icons
        ));
    }

    /**
     * Register frontend assets
     */
    public function register_frontend_assets() {
        // Only load if needed
        if (!is_singular() && !has_shortcode(get_the_content(), 'sssi')) {
            return;
        }

        wp_enqueue_style(
            'sssi-shared',
            SSSI_PLUGIN_URL . 'assets/css/sssi-shared.css',
            array(),
            SSSI_VERSION
        );

        wp_enqueue_style(
            'sssi-frontend',
            SSSI_PLUGIN_URL . 'assets/css/sssi-frontend.css',
            array('sssi-shared'),
            SSSI_VERSION
        );
    }

    /**
     * Get network icons
     */
    private function get_network_icons() {
        $networks = array('facebook', 'x', 'linkedin', 'pinterest', 'whatsapp', 'bluesky');
        $icons = array();
        
        foreach ($networks as $network) {
            $icons[$network] = SSSI_Icons::get_network_icon($network);
        }
        
        return $icons;
    }

    /**
     * Get default options
     */
    public static function get_default_options() {
        return array(
            'networks' => array('facebook', 'x', 'linkedin'),
            'share_text' => __('Share with friends:', 'super-simple-social-share-icons'),
            'icon_style' => 'brand',
            'icon_shape' => 'rounded',
            'alignment' => 'left',
            'text_position' => 'above',
            'position' => 'after',
            'text_style' => 'normal',
            'text_weight' => 'semibold',
            'text_size' => 18
        );
    }

    /**
     * Shortcode handler
     */
    public function render_shortcode($atts) {
        if (!$this->frontend) {
            $this->frontend = new SSSI_Frontend($this->settings);
        }
        return $this->frontend->shortcode_handler($atts);
    }
} 