<?php
/**
 * Frontend functionality class
 */

if (!defined('ABSPATH')) {
    exit;
}

class SSSI_Frontend {
    private $settings;

    public function __construct($settings) {
        $this->settings = $settings;
    }

    public function init() {
        // Add content filters based on position setting
        $options = $this->settings->get_options();
        $position = isset($options['position']) ? $options['position'] : 'after';
        
        if ($position !== 'shortcode') {
            if ($position === 'before' || $position === 'both') {
                add_filter('the_content', array($this, 'add_before_content'), 5);
            }
            if ($position === 'after' || $position === 'both') {
                add_filter('the_content', array($this, 'add_after_content'), 15);
            }
        }

        sssi_debug_log('Frontend initialized with position', array(
            'position' => $position,
            'options' => $options
        ));
    }

    /**
     * Get share URLs for the current page
     */
    private function get_share_urls() {
        $url = is_singular() ? get_permalink() : home_url('/');
        $title = is_singular() ? get_the_title() : get_bloginfo('name');
        
        $url = urlencode($url);
        $title = urlencode($title);
        
        return array(
            'facebook' => "https://www.facebook.com/sharer/sharer.php?u={$url}",
            'x' => "https://twitter.com/intent/tweet?url={$url}&text={$title}",
            'linkedin' => "https://www.linkedin.com/sharing/share-offsite/?url={$url}",
            'pinterest' => "https://pinterest.com/pin/create/button/?url={$url}&description={$title}",
            'whatsapp' => "https://wa.me/?text={$title}%20{$url}",
            'bluesky' => "https://bsky.app/intent/post?text={$title}%20{$url}"
        );
    }

    /**
     * Generate buttons HTML
     */
    private function get_buttons_html($instance_options = null) {
        $options = $instance_options ?? $this->settings->get_options();
        $share_urls = $this->get_share_urls();
        
        // Calculate button padding and size
        $icon_size = absint($options['icon_size']);
        $button_padding = round($icon_size * 0.3);
        $button_size = $icon_size + ($button_padding * 2);
        
        $style = array();
        $style[] = sprintf('--sssi-icon-size: %dpx', absint($icon_size));
        $style[] = sprintf('--sssi-button-padding: %dpx', absint($button_padding));
        $style[] = sprintf('--sssi-button-size: %dpx', absint($button_size));
        $style[] = sprintf('--sssi-spacing: %dpx', absint($options['icon_spacing']));
        $style[] = sprintf('--sssi-text-size: %dpx', absint($options['text_size']));
        
        // Add border radius based on shape
        switch ($options['icon_shape']) {
            case 'rounded':
                $style[] = '--sssi-border-radius: 8px';
                break;
            case 'circle':
                $style[] = '--sssi-border-radius: 50%';
                break;
            default:
                $style[] = '--sssi-border-radius: 0';
        }
        
        if ($options['icon_style'] === 'custom') {
            $style[] = sprintf('--sssi-custom-bg: %s', sanitize_hex_color($options['custom_bg_color'] ?? '#6B46C1'));
            $style[] = sprintf('--sssi-custom-icon: %s', sanitize_hex_color($options['custom_icon_color'] ?? '#FFFFFF'));
            $style[] = sprintf('--sssi-custom-border: %s', sanitize_hex_color($options['custom_border_color'] ?? '#E2E8F0'));
        }
        
        ob_start();
        ?>
        <div class="sssi-container sssi-style-<?php echo esc_attr($options['icon_style']); ?> sssi-shape-<?php echo esc_attr($options['icon_shape']); ?>"
             style="<?php echo esc_attr(implode('; ', array_map('esc_attr', $style))); ?>">
            <div class="sssi-content" 
                 data-text-position="<?php echo esc_attr($options['text_position']); ?>"
                 data-alignment="<?php echo esc_attr($options['alignment']); ?>"
                 data-text-style="<?php echo esc_attr($options['text_style']); ?>"
                 data-text-weight="<?php echo esc_attr($options['text_weight']); ?>">
                
                <?php if (!empty($options['share_text'])): ?>
                    <div class="sssi-title"><?php echo esc_html($options['share_text']); ?></div>
                <?php endif; ?>
                
                <div class="sssi-buttons">
                    <?php foreach ($options['networks'] as $network): ?>
                        <a href="<?php echo esc_url($share_urls[$network]); ?>" 
                           class="sssi-button sssi-<?php echo esc_attr($network); ?>"
                           data-network="<?php echo esc_attr($network); ?>"
                           target="_blank"
                           rel="noopener noreferrer">
                            <span class="sssi-icon" role="img" aria-label="<?php echo esc_attr(ucfirst($network)); ?>">
                                <?php 
                                $icon = SSSI_Icons::get_network_icon($network);
                                echo wp_kses($icon, SSSI_Icons::get_allowed_svg_attributes()); 
                                ?>
                            </span>
                        </a>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    /**
     * Shortcode handler
     */
    public function shortcode_handler($atts) {
        $options = $this->settings->get_options();
        
        $atts = shortcode_atts(array(
            'networks' => implode(',', $options['networks']),
            'style' => $options['icon_style'],
            'shape' => $options['icon_shape'],
            'text' => $options['share_text'],
            'position' => $options['text_position'],
            'align' => $options['alignment']
        ), $atts, 'sssi');

        $instance_options = array_merge($options, array(
            'networks' => explode(',', $atts['networks']),
            'icon_style' => $atts['style'],
            'icon_shape' => $atts['shape'],
            'share_text' => $atts['text'],
            'text_position' => $atts['position'],
            'alignment' => $atts['align']
        ));

        return $this->get_buttons_html($instance_options);
    }

    public function add_before_content($content) {
        // Only add to single posts, not pages or other post types
        if (!is_single() || !in_the_loop() || !is_main_query()) {
            return $content;
        }
        
        // Only add to 'post' post type, not custom post types
        if (get_post_type() !== 'post') {
            return $content;
        }
        
        sssi_debug_log('Adding share buttons before content');
        return $this->get_buttons_html() . $content;
    }

    public function add_after_content($content) {
        // Only add to single posts, not pages or other post types
        if (!is_single() || !in_the_loop() || !is_main_query()) {
            return $content;
        }
        
        // Only add to 'post' post type, not custom post types
        if (get_post_type() !== 'post') {
            return $content;
        }
        
        sssi_debug_log('Adding share buttons after content');
        return $content . $this->get_buttons_html();
    }

    private function get_allowed_svg_attributes() {
        return array(
            'svg' => array(
                'xmlns' => true,
                'viewBox' => true,
                'width' => true,
                'height' => true,
                'fill' => true,
                'class' => true,
                'style' => true,
                'preserveAspectRatio' => true,
                'aria-hidden' => true,
                'focusable' => true,
                'role' => true,
                'stroke' => true,
                'stroke-width' => true,
                'stroke-linecap' => true,
                'stroke-linejoin' => true,
                'version' => true,
                'id' => true,
                'x' => true,
                'y' => true,
                'enable-background' => true,
                'xml:space' => true,
            ),
            'g' => array(
                'fill' => true,
                'stroke' => true,
                'stroke-width' => true,
                'style' => true,
                'transform' => true,
            ),
            'title' => array('id' => true),
            'path' => array(
                'd' => true,
                'fill' => true,
                'fill-rule' => true,
                'stroke' => true,
                'stroke-width' => true,
                'stroke-linecap' => true,
                'stroke-linejoin' => true,
                'style' => true,
                'transform' => true,
                'clip-rule' => true,
            ),
            'rect' => array(
                'x' => true,
                'y' => true,
                'width' => true,
                'height' => true,
                'fill' => true,
                'stroke' => true,
                'stroke-width' => true,
                'style' => true,
                'transform' => true,
                'rx' => true,
                'ry' => true,
            ),
            'circle' => array(
                'cx' => true,
                'cy' => true,
                'r' => true,
                'fill' => true,
                'stroke' => true,
                'stroke-width' => true,
                'style' => true,
                'transform' => true,
            ),
        );
    }
} 