<?php
/**
 * Class for managing SVG icons
 *
 * @package SSSI
 */

if (!defined('ABSPATH')) {
    exit;
}

class SSSI_Icons {
    /**
     * Get SVG icon markup for a network
     *
     * @param string $network The social network identifier
     * @return string The sanitized SVG markup
     */
    public static function get_network_icon($network) {
        $icons = self::get_icons();
        if (!isset($icons[$network])) {
            return '';
        }

        // Use WordPress's wp_kses with specific SVG allowlist
        return wp_kses($icons[$network], self::get_allowed_svg_attributes());
    }

    /**
     * Get all available networks
     *
     * @return array List of available networks
     */
    public static function get_available_networks() {
        return array(
            'facebook' => __('Facebook', 'super-simple-social-share-icons'),
            'x' => __('X (Twitter)', 'super-simple-social-share-icons'),
            'linkedin' => __('LinkedIn', 'super-simple-social-share-icons'),
            'pinterest' => __('Pinterest', 'super-simple-social-share-icons'),
            'whatsapp' => __('WhatsApp', 'super-simple-social-share-icons'),
            'bluesky' => __('Bluesky', 'super-simple-social-share-icons')
        );
    }

    /**
     * Get network colors
     *
     * @return array Network colors
     */
    public static function get_network_colors() {
        return array(
            'facebook' => '#1877f2',
            'x' => '#000000',
            'linkedin' => '#0a66c2',
            'pinterest' => '#e60023',
            'whatsapp' => '#25d366',
            'bluesky' => '#0560ff'
        );
    }

    /**
     * Get allowed SVG attributes for wp_kses
     *
     * @return array Allowed SVG attributes
     */
    public static function get_allowed_svg_attributes() {
        return array(
            'svg' => array(
                'class' => true,
                'aria-hidden' => true,
                'aria-labelledby' => true,
                'role' => true,
                'xmlns' => true,
                'width' => true,
                'height' => true,
                'viewbox' => true,
                'fill' => true,
            ),
            'g' => array(
                'fill' => true,
                'transform' => true,
                'stroke' => true,
            ),
            'title' => array('id' => true),
            'path' => array(
                'd' => true,
                'fill' => true,
                'transform' => true,
                'stroke' => true,
                'stroke-width' => true,
            ),
        );
    }

    /**
     * Get all SVG icons
     *
     * @return array Array of SVG markup for each network
     */
    private static function get_icons() {
        return array(
            'facebook' => '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 16 16" fill="currentColor" aria-hidden="true" role="img"><path d="M16 8.049c0-4.446-3.582-8.05-8-8.05C3.58 0-.002 3.603-.002 8.05c0 4.017 2.926 7.347 6.75 7.951v-5.625h-2.03V8.05H6.75V6.275c0-2.017 1.195-3.131 3.022-3.131.876 0 1.791.157 1.791.157v1.98h-1.009c-.993 0-1.303.621-1.303 1.258v1.51h2.218l-.354 2.326H9.25V16c3.824-.604 6.75-3.934 6.75-7.951"/></svg>',
            'x' => '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 16 16" fill="currentColor" aria-hidden="true" role="img"><path d="M12.6.75h2.454l-5.36 6.142L16 15.25h-4.937l-3.867-5.07-4.425 5.07H.316l5.733-6.57L0 .75h5.063l3.495 4.633L12.601.75Zm-.86 13.028h1.36L4.323 2.145H2.865z"/></svg>',
            'linkedin' => '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 16 16" fill="currentColor" aria-hidden="true" role="img"><path d="M0 1.146C0 .513.526 0 1.175 0h13.65C15.474 0 16 .513 16 1.146v13.708c0 .633-.526 1.146-1.175 1.146H1.175C.526 16 0 15.487 0 14.854zm4.943 12.248V6.169H2.542v7.225zm-1.2-8.212c.837 0 1.358-.554 1.358-1.248-.015-.709-.52-1.248-1.342-1.248S2.4 3.226 2.4 3.934c0 .694.521 1.248 1.327 1.248zm4.908 8.212V9.359c0-.216.016-.432.08-.586.173-.431.568-.878 1.232-.878.869 0 1.216.662 1.216 1.634v3.865h2.401V9.25c0-2.22-1.184-3.252-2.764-3.252-1.274 0-1.845.7-2.165 1.193v.025h-.016l.016-.025V6.169h-2.4c.03.678 0 7.225 0 7.225z"/></svg>',
            'pinterest' => '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="currentColor" aria-hidden="true" role="img"><path d="M12 0C5.372 0 0 5.372 0 12c0 5.08 3.162 9.408 7.611 11.066-.104-.939-.2-2.384.042-3.415.22-.943 1.42-5.993 1.42-5.993s-.363-.725-.363-1.799c0-1.687.98-2.947 2.199-2.947 1.036 0 1.537.777 1.537 1.708 0 1.04-.66 2.591-1 4.027-.284 1.197.602 2.175 1.79 2.175 2.146 0 3.791-2.26 3.791-5.512 0-2.883-2.075-4.9-5.037-4.9-3.434 0-5.448 2.573-5.448 5.232 0 1.038.396 2.153.891 2.755.098.118.112.222.083.34-.09.372-.298 1.197-.338 1.36-.053.223-.175.271-.403.164-1.504-.699-2.438-2.893-2.438-4.658 0-3.79 2.745-7.274 7.907-7.274 4.14 0 7.356 2.957 7.356 6.906 0 4.107-2.594 7.413-6.188 7.413-1.206 0-2.339-.627-2.722-1.373 0 0-.647 2.574-.804 3.113-.293 1.073-1.09 2.407-1.623 3.23C8.734 23.749 10.332 24 12 24c6.628 0 12-5.372 12-12S18.628 0 12 0z"/></svg>',
            'whatsapp' => '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 32 32" fill="currentColor" aria-hidden="true" role="img"><path d="M15.565 0C7.057 0 .133 6.669.13 14.865c-.002 2.621.71 5.179 2.06 7.432L0 30l8.183-2.067a15.89 15.89 0 007.376 1.81h.006c8.508 0 15.432-6.67 15.435-14.866.002-3.97-1.602-7.707-4.517-10.516C23.569 1.551 19.694.001 15.565 0zm0 27.232h-.005c-2.302 0-4.56-.596-6.53-1.722l-.47-.268-4.854 1.226 1.296-4.56-.305-.467a11.983 11.983 0 01-1.962-6.576C2.738 8.052 8.494 2.511 15.57 2.511c3.426.001 6.647 1.288 9.07 3.623s3.756 5.44 3.754 8.742c-.003 6.813-5.758 12.356-12.83 12.356zm7.037-9.255c-.386-.185-2.282-1.084-2.636-1.209-.353-.123-.61-.187-.867.185-.256.372-.996 1.209-1.22 1.456-.226.248-.451.278-.837.093-.386-.186-1.629-.578-3.101-1.844-1.147-.984-1.921-2.2-2.146-2.573-.225-.371-.024-.572.169-.757.173-.165.386-.433.578-.65.192-.217.256-.372.386-.62.128-.247.064-.465-.033-.65-.097-.187-.867-2.015-1.19-2.758-.312-.724-.63-.627-.867-.639-.225-.01-.481-.013-.74-.013-.255 0-.674.093-1.028.465-.353.372-1.35 1.27-1.35 3.098 0 1.829 1.382 3.595 1.575 3.843.193.247 2.72 4 6.589 5.61.92.381 1.638.61 2.199.782.924.283 1.765.242 2.429.147.74-.107 2.282-.898 2.602-1.765.322-.867.322-1.611.226-1.766-.094-.155-.352-.248-.738-.435z"/></svg>',
            'bluesky' => '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 64 57" fill="currentColor" aria-hidden="true" role="img"><path d="M13.873 3.805C21.21 9.332 29.103 20.537 32 26.55v15.882c0-.338-.13.044-.41.867-1.512 4.456-7.418 21.847-20.923 7.944-7.111-7.32-3.819-14.64 9.125-16.85-7.405 1.264-15.73-.825-18.014-9.015C1.12 23.022 0 8.51 0 6.55 0-3.268 8.579-.182 13.873 3.805ZM50.127 3.805C42.79 9.332 34.897 20.537 32 26.55v15.882c0-.338.13.044.41.867 1.512 4.456 7.418 21.847 20.923 7.944 7.111-7.32 3.819-14.64-9.125-16.85 7.405 1.264 15.73-.825 18.014-9.015C62.88 23.022 64 8.51 64 6.55c0-9.818-8.578-6.732-13.873-2.745Z"/></svg>'
        );
    }
} 