<?php
/**
 * Settings management class
 *
 * @package SSSI
 */

if (!defined('ABSPATH')) {
    die;
}

class SSSI_Settings {
    private $options;
    private $default_options;

    public function __construct() {
        $this->default_options = array(
            'networks' => array('facebook', 'x', 'linkedin'),
            'icon_style' => 'brand',
            'icon_shape' => 'rounded',
            'alignment' => 'left',
            'text_position' => 'above',
            'share_text' => esc_html__('Share with friends:', 'super-simple-social-share-icons'),
            'position' => 'after',
            'icon_size' => 24,
            'icon_spacing' => 8,
            'text_style' => 'normal',
            'text_weight' => 'normal',
            'text_size' => 18,
            'custom_bg_color' => '#6B46C1',
            'custom_icon_color' => '#FFFFFF',
            'custom_border_color' => '#E2E8F0'
        );
        
        // Get options with defaults
        $this->options = wp_parse_args(
            get_option('sssi_options', array()),
            $this->default_options
        );

        // Add hooks after options are initialized
        add_action('admin_menu', array($this, 'add_settings_page'));
        add_action('admin_init', array($this, 'register_settings'));
        
        // Add AJAX handlers
        add_action('wp_ajax_save_sssi_settings', array($this, 'ajax_save_settings'));
    }

    public function add_settings_page() {
        add_menu_page(
            esc_html__('Social Share Settings', 'super-simple-social-share-icons'),
            esc_html__('Social Share', 'super-simple-social-share-icons'),
            'manage_options',
            'sssi-settings',
            array($this, 'render_settings_page'),
            'dashicons-share',
            30
        );
    }

    public function render_settings_page() {
        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('You do not have sufficient permissions to access this page.', 'super-simple-social-share-icons'));
        }

        try {
            // Add nonce field for settings form
            wp_nonce_field('sssi_settings_nonce', 'sssi_settings_nonce');
            
            require_once SSSI_PLUGIN_DIR . 'templates/admin-settings.php';
            
        } catch (Exception $e) {
            sssi_debug_log('Settings page render failed', array(
                'error' => $e->getMessage(),
                'trace' => $e->getTraceAsString()
            ));
            
            echo '<div class="notice notice-error"><p>';
            esc_html_e('Error loading settings page. Please check the debug log.', 'super-simple-social-share-icons');
            echo '</p></div>';
        }
    }

    public function get_options() {
        return wp_parse_args($this->options, $this->default_options);
    }

    public function register_settings() {
        register_setting(
            'sssi_options_group',
            'sssi_options',
            array(
                'type' => 'array',
                'sanitize_callback' => array($this, 'sanitize_options'),
                'default' => $this->default_options
            )
        );

        add_settings_section(
            'sssi_platforms_section',
            '',
            null,
            'sssi_settings'
        );

        add_settings_section(
            'sssi_appearance_section',
            '',
            null,
            'sssi_settings'
        );

        add_settings_section(
            'sssi_position_section',
            '',
            null,
            'sssi_settings'
        );

        add_settings_section(
            'sssi_text_section',
            '',
            null,
            'sssi_settings'
        );
    }

    public function sanitize_options($input) {
        $sanitized = array();
        
        // Networks array
        if (isset($input['networks']) && is_array($input['networks'])) {
            $sanitized['networks'] = array_map('sanitize_text_field', $input['networks']);
        }
        
        // Text fields
        $text_fields = ['share_text', 'text_style', 'text_weight'];
        foreach ($text_fields as $field) {
            $sanitized[$field] = isset($input[$field]) ? sanitize_text_field($input[$field]) : '';
        }
        
        // Numeric fields
        $numeric_fields = ['icon_size', 'icon_spacing', 'text_size'];
        foreach ($numeric_fields as $field) {
            $sanitized[$field] = isset($input[$field]) ? absint($input[$field]) : 0;
        }
        
        // Color fields
        $color_fields = ['custom_bg_color', 'custom_icon_color', 'custom_border_color'];
        foreach ($color_fields as $field) {
            $sanitized[$field] = isset($input[$field]) ? sanitize_hex_color($input[$field]) : '';
        }
        
        // Radio/select fields with specific valid values
        $sanitized['icon_style'] = isset($input['icon_style']) && in_array($input['icon_style'], ['brand', 'dark', 'light', 'custom']) 
            ? $input['icon_style'] : 'brand';
        
        $sanitized['icon_shape'] = isset($input['icon_shape']) && in_array($input['icon_shape'], ['rounded', 'square', 'circle']) 
            ? $input['icon_shape'] : 'rounded';
        
        $sanitized['alignment'] = isset($input['alignment']) && in_array($input['alignment'], ['left', 'center', 'right']) 
            ? $input['alignment'] : 'left';
        
        $sanitized['position'] = isset($input['position']) && in_array($input['position'], ['before', 'after', 'both', 'shortcode']) 
            ? $input['position'] : 'after';
        
        $sanitized['text_position'] = isset($input['text_position']) && in_array($input['text_position'], ['above', 'below', 'left']) 
            ? $input['text_position'] : 'above';
        
        return $sanitized;
    }

    /**
     * AJAX handler for saving settings
     */
    public function ajax_save_settings() {
        try {
            // Verify nonce first
            if (!check_ajax_referer('sssi_settings_nonce', 'nonce', false)) {
                throw new Exception(
                    esc_html__('Security verification failed. Please refresh the page and try again.', 'super-simple-social-share-icons')
                );
            }

            // Check user capabilities
            if (!current_user_can('manage_options')) {
                throw new Exception(
                    esc_html__('You do not have permission to perform this action.', 'super-simple-social-share-icons')
                );
            }

            // Get and validate form data
            $form_data = filter_input(INPUT_POST, 'form_data', FILTER_SANITIZE_STRING);
            if (!$form_data) {
                throw new Exception(
                    esc_html__('No form data received.', 'super-simple-social-share-icons')
                );
            }

            // Parse form data
            wp_parse_str($form_data, $parsed_data);

            // Log raw data for debugging
            sssi_debug_log('Raw form data:', $parsed_data);

            // Validate the form structure
            if (!isset($parsed_data['sssi_options']) || !is_array($parsed_data['sssi_options'])) {
                throw new Exception(
                    esc_html__('Invalid form structure', 'super-simple-social-share-icons')
                );
            }

            // Build and sanitize options array
            $new_options = $this->sanitize_form_data($parsed_data['sssi_options']);

            // Log sanitized options
            sssi_debug_log('Sanitized options:', $new_options);

            // Update options
            $updated = update_option('sssi_options', $new_options);

            if ($updated) {
                wp_send_json_success([
                    'message' => esc_html__('Settings saved successfully', 'super-simple-social-share-icons'),
                    'options' => $new_options
                ]);
            } else {
                $existing_options = get_option('sssi_options', array());
                if ($existing_options === $new_options) {
                    wp_send_json_success([
                        'message' => esc_html__('No changes were necessary', 'super-simple-social-share-icons'),
                        'options' => $new_options
                    ]);
                } else {
                    throw new Exception(
                        esc_html__('Failed to save settings', 'super-simple-social-share-icons')
                    );
                }
            }

        } catch (Exception $e) {
            sssi_debug_log('Settings save error:', array(
                'message' => $e->getMessage(),
                'trace' => $e->getTraceAsString()
            ));
            
            wp_send_json_error([
                'message' => esc_html($e->getMessage())
            ]);
        }
    }

    /**
     * Sanitize form data
     *
     * @param array $data Raw form data
     * @return array Sanitized data
     */
    private function sanitize_form_data($data) {
        $sanitized = array();
        
        // Networks array
        if (isset($data['networks']) && is_array($data['networks'])) {
            $allowed_networks = array_keys(SSSI_Icons::get_available_networks());
            $sanitized['networks'] = array_filter(
                array_map('sanitize_text_field', $data['networks']),
                function($network) use ($allowed_networks) {
                    return in_array($network, $allowed_networks);
                }
            );
        } else {
            $sanitized['networks'] = array('facebook', 'x', 'linkedin'); // Default networks
        }
        
        // Text fields with default values
        $text_fields = array(
            'share_text' => esc_html__('Share with friends:', 'super-simple-social-share-icons'),
            'text_style' => 'normal',
            'text_weight' => 'normal'
        );
        
        foreach ($text_fields as $field => $default) {
            $sanitized[$field] = isset($data[$field]) ? sanitize_text_field($data[$field]) : $default;
        }
        
        // Numeric fields with default values
        $numeric_fields = array(
            'icon_size' => 24,
            'icon_spacing' => 8,
            'text_size' => 16
        );
        
        foreach ($numeric_fields as $field => $default) {
            $sanitized[$field] = isset($data[$field]) ? absint($data[$field]) : $default;
        }
        
        // Color fields with default values
        $color_fields = array(
            'custom_bg_color' => '#6B46C1',
            'custom_icon_color' => '#FFFFFF',
            'custom_border_color' => '#E2E8F0'
        );
        
        foreach ($color_fields as $field => $default) {
            $sanitized[$field] = isset($data[$field]) ? sanitize_hex_color($data[$field]) : $default;
        }
        
        // Validate select/radio fields
        $select_fields = array(
            'icon_style' => array('brand', 'dark', 'light', 'custom'),
            'icon_shape' => array('rounded', 'square', 'circle'),
            'alignment' => array('left', 'center', 'right'),
            'position' => array('before', 'after', 'both', 'shortcode'),
            'text_position' => array('above', 'below', 'left'),
            'text_style' => array('normal', 'underline', 'uppercase', 'italic')
        );
        
        foreach ($select_fields as $field => $allowed_values) {
            $value = isset($data[$field]) ? sanitize_text_field($data[$field]) : '';
            $sanitized[$field] = in_array($value, $allowed_values) ? $value : $allowed_values[0];
        }
        
        return $sanitized;
    }
} 