<?php
/**
 * Plugin Name: Super Simple Social Share Icons
 * Plugin URI: https://voltblocks.com/plugins/super-simple-social-share-icons
 * Description: A lightweight and powerful solution for adding social sharing to your WordPress site.
 * Version: 1.0.0
 * Author: Volt Blocks
 * Author URI: https://voltblocks.com
 * Text Domain: super-simple-social-share-icons
 * Domain Path: /languages
 * License: GPL v2 or later
 */

if (!defined('ABSPATH')) {
    exit;
}

// Plugin constants
define('SSSI_VERSION', '1.0.0');
define('SSSI_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('SSSI_PLUGIN_URL', plugin_dir_url(__FILE__));
define('SSSI_PLUGIN_BASENAME', plugin_basename(__FILE__));

// Add after constants and before includes
if (!function_exists('sssi_debug_log')) {
    /**
     * Log debug messages in a standardized format
     *
     * @param string|mixed $message The message to log
     * @param array|null   $data    Optional data to include
     * @param string       $context Optional context identifier
     */
    function sssi_debug_log($message, $data = null, $context = '') {
        if (!defined('WP_DEBUG') || !WP_DEBUG) {
            return;
        }
        
        $timestamp = gmdate('[Y-m-d H:i:s]');
        $context_str = $context ? "[$context] " : '';
        
        // Convert message to string if it's not already
        $log_message = $timestamp . ' [SSSI] ' . $context_str;
        $log_message .= is_string($message) ? $message : wp_json_encode($message);
        
        // Add data if provided
        if ($data !== null) {
            $log_message .= "\nData: " . wp_json_encode($data, JSON_PRETTY_PRINT);
        }
        
        // Only log if WP_DEBUG_LOG is enabled
        if (defined('WP_DEBUG_LOG') && WP_DEBUG_LOG) {
            // Use WordPress logging function if available
            if (function_exists('wp_debug_log')) {
                wp_debug_log($log_message);
            } else {
                // Use WP_Filesystem for file operations
                require_once ABSPATH . 'wp-admin/includes/file.php';
                WP_Filesystem();
                global $wp_filesystem;

                if ($wp_filesystem) {
                    $upload_dir = wp_upload_dir();
                    $log_file = $upload_dir['basedir'] . '/sssi-debug.log';
                    
                    // Only write if logging is explicitly enabled
                    if (apply_filters('sssi_should_log_debug', true, $message, $data, $context)) {
                        $log_message .= "\n";
                        
                        // Append to file using WP_Filesystem
                        if ($wp_filesystem->exists($log_file)) {
                            $existing_content = $wp_filesystem->get_contents($log_file);
                            $wp_filesystem->put_contents($log_file, $existing_content . $log_message, FS_CHMOD_FILE);
                        } else {
                            $wp_filesystem->put_contents($log_file, $log_message, FS_CHMOD_FILE);
                        }
                    }
                }
            }
        }
    }
}

// After plugin constants and before includes
function sssi_load_textdomain() {
    load_plugin_textdomain(
        'super-simple-social-share-icons',
        false,
        dirname(SSSI_PLUGIN_BASENAME) . '/languages'
    );
}
add_action('plugins_loaded', 'sssi_load_textdomain');

// Required files
require_once SSSI_PLUGIN_DIR . 'includes/class-sssi-icons.php';
require_once SSSI_PLUGIN_DIR . 'includes/class-sssi-settings.php';
require_once SSSI_PLUGIN_DIR . 'includes/class-sssi-frontend.php';
require_once SSSI_PLUGIN_DIR . 'includes/class-sssi-core.php';

// Initialize plugin
function sssi_init() {
    try {
        // Initialize core
        new SSSI_Core();
        
        sssi_debug_log('Plugin initialized successfully');
    } catch (Exception $e) {
        sssi_debug_log('Plugin initialization failed', array(
            'error' => $e->getMessage(),
            'trace' => $e->getTraceAsString()
        ), 'CRITICAL');
        
        if (is_admin()) {
            add_action('admin_notices', function() use ($e) {
                printf(
                    '<div class="notice notice-error"><p>%s</p></div>',
                    esc_html($e->getMessage())
                );
            });
        }
    }
}

add_action('plugins_loaded', 'sssi_init');

// Activation hook
register_activation_hook(__FILE__, function() {
    // Version checks
    if (version_compare(get_bloginfo('version'), '5.0', '<')) {
        wp_die('This plugin requires WordPress 5.0 or higher');
    }
    
    if (version_compare(PHP_VERSION, '7.0', '<')) {
        wp_die('This plugin requires PHP 7.0 or higher');
    }

    // Get existing options
    $existing_options = get_option('sssi_options');
    
    if ($existing_options) {
        // Migrate twitter to x in networks array
        if (isset($existing_options['networks']) && is_array($existing_options['networks'])) {
            $existing_options['networks'] = array_map(function($network) {
                return $network === 'twitter' ? 'x' : $network;
            }, $existing_options['networks']);
            update_option('sssi_options', $existing_options);
        }
    } else {
        // Set default options with 'x' instead of 'twitter'
        update_option('sssi_options', array(
            'networks' => array('facebook', 'x', 'linkedin'),
            'share_text' => __('Share with friends:', 'super-simple-social-share-icons'),
            'icon_style' => 'brand',
            'icon_shape' => 'rounded',
            'alignment' => 'left',
            'text_position' => 'above',
            'position' => 'after'
        ));
    }
});

// Update shortcode registration
add_shortcode('super_simple_share', function($atts) {
    if (!isset($GLOBALS['sssi_core'])) {
        $GLOBALS['sssi_core'] = new SSSI_Core();
    }
    return $GLOBALS['sssi_core']->render_shortcode($atts);
});